from django.utils import timezone
from django.db import models

from account.models import Account


class ExpenseType(models.Model):
    name = models.CharField(max_length=255)

    def __str__(self):
        return self.name


class ExpenseItem(models.Model):
    name = models.CharField(max_length=255)
    expense_type = models.ForeignKey(ExpenseType, on_delete=models.CASCADE, null=True, blank=True)
    transaction_id = models.CharField(max_length=255, unique=True, null=True)
    date = models.DateField()
    amount = models.DecimalField(max_digits=10, decimal_places=2)
    description = models.TextField()
    created_at = models.DateTimeField(default=timezone.now)
    updated_at = models.DateTimeField(auto_now=True)
    document = models.FileField(upload_to='expenses/documents/', blank=True, null=True)
    requested_by = models.ForeignKey(Account, on_delete=models.SET_NULL, null=True, blank=True,
                                     related_name='requested_expenses')
    kra_etr = models.CharField(max_length=255, null=True)
 

# python manage.py shell

# EXPENSE_TYPE_CHOICES = [
#     ('advertising_marketing', 'Advertising & Marketing'),
#     ('accounting_fees', 'Accounting Fees'),
#     ('cleaning_sanitation', 'Cleaning & Sanitation'),
#     ('licenses', 'Licenses'),
#     ('insurance', 'Insurance'),
#     ('internet_expenses', 'Internet Expenses'),
#     ('legal_professional', 'Legal and Professional'),
#     ('office_errand', 'Office Errand Expenses'),
#     ('office_expenses', 'Office Expenses'),
#     ('computer_running', 'Computer Running Expenses'),
#     ('transport_costs', 'Transport Costs'),
#     ('office_meals', 'Office Meals'),
#     ('printing_stationery', 'Printing & Stationery Expenses'),
#     ('salary', 'Salary'),
#     ('repairs_maintenance', 'Repairs & Maintenance'),
#     ('travel_accommodation', 'Travel and Accommodation'),
#     ('vehicle_running', 'Vehicle Running Expenses'),
#     ('consumables', 'Consumables'),
#     ('rent', 'Rent'),
#     ('stock', 'Stock'),
#     ('utilities', 'Utilities'),
#     ('telephone_airtime', 'Telephone & Airtime'),
#     ('it_costs', 'IT Costs'),
#     ('water', 'Water'),
# ]

# from expenses.models import ExpenseType

# # Iterate over the choices and create ExpenseType instances
# for choice in EXPENSE_TYPE_CHOICES:
#     name, _ = choice
#     ExpenseType.objects.create(name=name)

# # Verify the inserted data
# ExpenseType.objects.all()
